diff --git a/chrome/content/zotero/fileInterface.js b/chrome/content/zotero/fileInterface.js
index c5d2b583e3..9a4ef758c9 100644
--- a/chrome/content/zotero/fileInterface.js
+++ b/chrome/content/zotero/fileInterface.js
@@ -93,10 +93,11 @@ Zotero_File_Exporter.prototype.save = async function () {
 				}
 			}
 		}
-		// Otherwise exclude note export translators
-		else {
-			translators = translators.filter(t => !t.configOptions || !t.configOptions.noteTranslator);
-		}
+	}
+
+	// Exclude note translators if not exporting notes
+	if (!exportingNotes) {
+		translators = translators.filter(t => !t.configOptions || !t.configOptions.noteTranslator);
 	}
 	
 	// present options dialog